@@ -46,8 +46,7 @@
 #'   `Specs', and `ErrM', and these override the corresponding input parameters.
 #'   Not all of these elements need to be present, and all other elements are
 #'   ignored. If \code{SeqList$Specs} is provided, all  input parameters with
-#'   the same name as its items are ignored, except
-#'   \code{Module}/\code{MaxSibIter}.
+#'   the same name as its items are ignored, except \code{Module}.
 #' @param Module one of
 #'   \describe{
 #'     \item{pre}{Only input check, return \code{SeqList$Specs}}
@@ -58,20 +57,19 @@
 #'       sibship clustering and grandparent assignment. By far the most time
 #'       consuming, and may take several hours for large datasets.}
 #'   }
-#'   NOTE: \emph{Until `MaxSibIter` is fully deprecated: if `MaxSibIter` differs
-#'   from the default (\code{42}), and `Module` equals the default
-#'   (\code{'ped'}), MaxSibIter overrides `Module`.}
-#' @param Err estimated genotyping error rate, as a single number, or a length 3
-#'   vector with P(hom|hom), P(het|hom), P(hom|het), or a 3x3 matrix. See
-#'   details below. The error rate is presumed constant across SNPs, and
+#' @param Err assumed per-locus genotyping error rate, as a single number, or a
+#'   length 3 vector with P(hom|hom), P(het|hom), P(hom|het), or a 3x3 matrix.
+#'   See details below. The error rate is presumed constant across SNPs, and
 #'   missingness is presumed random with respect to actual genotype. Using
 #'   \code{Err} >5\% is not recommended, and \code{Err} >10\% strongly
-#'   discouraged.
+#'   discouraged. See \code{\link{Err_RADseq}} to convert per-allele rates at
+#'   homozygous and heterozygous sites to the required length-3 vector, and
+#'   \code{\link{ErrToM}} for further genotyping error details.
 #' @param ErrFlavour function that takes \code{Err} (single number) as input,
 #'   and returns a length 3 vector or 3x3 matrix, or choose from inbuilt options
 #'   'version2.9', 'version2.0', 'version1.3', or 'version1.1', referring to the
 #'   sequoia version in which they were the default. Ignored if \code{Err} is a
-#'   vector or matrix. See \code{\link{ErrToM}} for details.
+#'   vector or matrix.
 #' @param Tfilter threshold log10-likelihood ratio (LLR) between a proposed
 #'   relationship versus unrelated, to select candidate relatives. Typically a
 #'   negative value, related to the fact that unconditional likelihoods are
@@ -119,15 +117,6 @@
 #'   the unavoidable default up to version 2.4.1. Otherwise only excluded are
 #'   (very nearly) monomorphic SNPs, SNPs scored for fewer than 2 individuals,
 #'   and individuals scored for fewer than 2 SNPs.
-#' @param MaxSibIter \strong{DEPRECATED, use \code{Module}} number of iterations
-#'   of sibship clustering, including assignment of grandparents to sibships and
-#'   avuncular relationships between sibships. Clustering continues until
-#'   convergence or until MaxSibIter is reached. Set to 0 for parentage
-#'   assignment only.
-#' @param MaxMismatch \strong{DEPRECATED AND IGNORED}. Now calculated
-#'   automatically using \code{\link{CalcMaxMismatch}}.
-#' @param FindMaybeRel \strong{DEPRECATED AND IGNORED}, advised to run
-#'   \code{\link{GetMaybeRel}} separately.
 #'
 #'
 #' @return A list with some or all of the following components, depending on
@@ -243,10 +232,15 @@
 #'    data
 #'  }
 #'  All pairs of non-assigned but likely/definitely relatives can be found with
-#'  \code{\link{GetMaybeRel}}. For a method to do pairwise 'assignments', see
+#'  \code{\link{GetMaybeRel}} (run without conditioning on a pedigree). For a
+#'  method to do pairwise 'assignments', see
 #'  https://jiscah.github.io/articles/pairLL_classification.html ; for further
 #'  information, see the vignette.
 #'
+#'  If you already had a partial pedigree, running \code{\link{CalcOHLLR}} or
+#'  \code{\link{CalcParentProbs}} on it with the new SNP data and various
+#'  parameter value combinations may be informative.
+#'
 #' @section Disclaimer:
 #' While every effort has been made to ensure that sequoia provides what it
 #' claims to do, there is absolutely no guarantee that the results provided are
@@ -274,6 +268,8 @@
 #'   \item \code{\link{GetRelM}} to turn a pedigree into pairwise relationships,
 #'   \item \code{\link{CalcOHLLR}} to calculate Mendelian errors and LLR for any
 #'    pedigree,
+#'   \item \code{\link{CalcParentProbs}} to calculate assignment probabilities
+#'   instead of LLRs,
 #'   \item \code{\link{CalcPairLL}} for likelihoods of various relationships
 #'    between specific pairs,
 #'   \item \code{\link{CalcBYprobs}} to estimate birth years,
@@ -335,7 +331,10 @@
 #' write.table(GenoM, file="MyGenoData.txt", row.names=T, col.names=F)
 #'
 #' # later:
-#' GenoM <- as.matrix(read.table("MyGenoData.txt", row.names=1, header=F))
+#' GenoM <- as.matrix(read.table("MyGenoData.txt", row.names=1, header=FALSE))
+#' # or for very large datasets:
+#' GenoM <- data.table::fread('MyGenoData.txt') %>% as.matrix(rownames=1)
+#'
 #' LHdata <- read.table("LifeHistoryData.txt", header=T) # ID-Sex-birthyear
 #' SeqOUT <- sequoia(GenoM, LHdata, Err=0.005)
 #' SummarySeq(SeqOUT)
@@ -364,16 +363,12 @@ sequoia <- function(GenoM = NULL,
                     UseAge = "yes",
                     args.AP = list(Flatten=NULL, Smooth=TRUE),
                     mtSame = NULL,
-                    CalcLLR = TRUE,
+                    CalcLLR = FALSE,
                     quiet = FALSE,
                     Plot = NULL,
                     StrictGenoCheck = TRUE,
-                    ErrFlavour = "version2.9",
-                    MaxSibIter = 42,  # DEPRECATED
-                    MaxMismatch = NA,  # DEPRECATED
-                    FindMaybeRel = FALSE)  # DEPRECATED
+                    ErrFlavour = "version2.9")
 {
-
   TimeStart <- Sys.time()
 
   # set quiet & Plot ----
@@ -383,34 +378,14 @@ sequoia <- function(GenoM = NULL,
   if (is.null(Plot))   # default
     Plot <- ifelse(quietR, FALSE, TRUE)
 
-  # Backwards compatibility: Module vs MaxSibIter ----
-  # if MaxSibIter is not default (42), and Module is default (ped), MaxSibIter overrides Module
-  if (MaxSibIter != 42 && Module == "ped") {
-    Module <- cut(MaxSibIter,
-                  breaks= c(-Inf, -9, -1, 0, Inf),
-                  labels = c("pre", "dup", "par", "ped"))
-    if (!quietR)  cli::cli_alert_warning(c("`MaxSibIter` will be deprecated, ",
-      "please use `Module` instead"))
-  } else {
-    Module <- factor(Module, levels = c("pre", "dup", "par", "ped"))
-    if (is.na(Module))  stop("'Module'  must be 'pre', 'dup', 'par', or 'ped'")
-  }
-
-  if (FindMaybeRel)
-    cli::cli_alert_warning(c("`FindMaybeRel` has been deprecated and is ignored,",
-            "instead run `GetMaybeRel()` afterwards"))
-  if (!is.na(MaxMismatch))
-    cli::cli_alert_warning(c("`MaxMismatch` has been deprecated and is ignored,",
-            "now calculated automatically via `CalcMaxMismatch()`"))
-
+  # check input ----
   if (!is.null(LifeHistData) & !inherits(LifeHistData, 'data.frame'))
     stop("`LifeHistData` must be a data.frame or NULL")
   if (!is.null(SeqList) & !inherits(SeqList, 'list'))
     stop("`SeqList` must be a list or `NULL`")
 
   if (!is.null(SeqList)) {
-    SeqList_names <- c("Specs", "ErrM", "args.AP", "AgePriors", "LifeHist",
-                       "PedigreePar", "MaxSibIter")
+    SeqList_names <- c("Specs", "ErrM", "args.AP", "AgePriors", "LifeHist","PedigreePar")
     if (!any(names(SeqList) %in% SeqList_names) | any(is.na(names(SeqList))) ) {
       cli::cli_alert_danger("You seem to have misspelled one or more names of elements of `SeqList`:")
       cli::cli_li(setdiff(names(SeqList), SeqList_names))
@@ -419,6 +394,22 @@ sequoia <- function(GenoM = NULL,
   }
 
 
+  # Module ----
+  # MaxSibIter is now fully deprecated.
+  Module <- factor(Module, levels = c("pre", "dup", "par", "ped"))
+  if (is.na(Module))  stop("'Module'  must be 'pre', 'dup', 'par', or 'ped'")
+  dostep <- c('pre' = TRUE,
+              'dup' = Module!='pre',
+              'par' = Module %in% c('par','ped'),
+              'ped' = Module=='ped')
+  if ('DupGenotype' %in% names(SeqList))  dostep['dup'] <- FALSE
+  if ('PedigreePar' %in% names(SeqList) & Module=='ped')  dostep['par'] <- FALSE
+  # module='par' + PedigreePar: parentage assignment with pedigree-prior
+  # for output:
+  DupList <- NULL
+  ParList <- NULL
+  SibList <- NULL
+
   # Check genotype matrix ----
   GenoM[is.na(GenoM)] <- -9
   if (!quietR) cli::cli_alert_info("Checking input data ...")
@@ -481,16 +472,6 @@ sequoia <- function(GenoM = NULL,
                                          args.AP))
   }
 
-
-  # Check Pedigree ----
-  if ("PedigreePar" %in% names(SeqList) & Module != "dup") {
-    if (!quietR)  cli::cli_alert_info("using `PedigreePar` in `SeqList`")
-    PedParents <- PedPolish(SeqList[["PedigreePar"]], gID = rownames(GenoM),
-                            ZeroToNA = TRUE, DropNonSNPd = TRUE)
-  } else {
-    PedParents <- NULL
-  }
-
   utils::flush.console()
 
   # check & reformat mitochondrial same/not matrix
@@ -500,7 +481,6 @@ sequoia <- function(GenoM = NULL,
   if ("Specs" %in% names(SeqList)) {
     PARAM <- SpecsToParam(SeqList$Specs, SeqList$ErrM, ErrFlavour,  # re-wrapping + ErrToM check
                           dimGeno = dim(GenoM), Module, quiet) # overrule old values
-    if (Module=="ped")  PARAM$MaxSibIter <- 42
   } else {
     if (is.logical(UseAge))   UseAge <- ifelse(UseAge, "yes", "no")
     if ((Herm != "no" | any(LifeHistData$Sex==4, na.rm=TRUE)) & length(DummyPrefix)==2)
@@ -514,7 +494,6 @@ sequoia <- function(GenoM = NULL,
                        nAgeClasses = nrow(AgePriors),
                        MaxSibshipSize,
                        Module = as.character(Module),
-                       MaxSibIter,
                        DummyPrefix,
                        Complex,
                        Herm,
@@ -536,7 +515,7 @@ sequoia <- function(GenoM = NULL,
   }
 
 
-  # hermaprhodites ----
+  # hermaphrodites ----
   if (any(LifeHistData$Sex==4, na.rm=TRUE) && PARAM$Herm == "no") {  #!grepl("herm", PARAM$Complex)) {
     if (!quietR) cli::cli_alert_warning("Detected hermaphrodites (sex=4), changing `Herm` to 'A'")
 #    PARAM$Complex <- "herm"
@@ -555,22 +534,39 @@ sequoia <- function(GenoM = NULL,
 
 
   # @@ 2 @@ Duplicate check ----
-  if (Module != "pre") {
+  if (dostep[['dup']]) {
     if(!quietR)  message(cli::col_green("\n~~~ Duplicate check ~~~"))
     DupList <- DuplicateCheck(GenoM, FortPARAM, quiet=quietR)
     utils::flush.console()
-    if ("DupGenoID" %in% names(DupList)) {  # fatal error  (message by duplicateCheck())
+    if ("DupGenoID" %in% names(DupList)) {  # fatal error  (message by DuplicateCheck())
       return(DupList)
     } else if (length(DupList)==0 & !quietR) {
       cli::cli_alert_success("No potential duplicates found")
+    } else if ('DupGenotype' %in% names(DupList) && nrow(DupList[['DupGenotype']])>=nrow(GenoM)) {
+      Sys.sleep(1)   # ensures warnings are printed first
+      cli::cli_alert_danger(cli::col_red(paste('The high number of putative duplicate genotypes suggests',
+                                  'that the genotype data is not informative enough for',
+                                  'parentage assignment. Interpret results with caution!')), wrap=TRUE)
+      # dostep[c('par', 'ped')] <- FALSE
     }
-  } else DupList <- NULL
+  }
   utils::flush.console()
 
 
   # @@ 3 @@ Parentage assignment ----
-  if (Module == "par"  | (Module  == "ped" & is.null(PedParents))) {
-    if(!quietR & Module == "par" & !is.null(PedParents)) {
+  if (any(dostep[c('par', 'ped')]) & "PedigreePar" %in% names(SeqList)) {
+    if (!quietR) {
+      message(cli::col_green("\n~~~ Parentage assignment ~~~"))
+      cli::cli_alert_info("using `PedigreePar` in `SeqList`")
+    }
+    PedParents <- PedPolish(SeqList[["PedigreePar"]], gID = rownames(GenoM),
+                            ZeroToNA = TRUE, DropNonSNPd = TRUE)
+  } else {
+    PedParents <- NULL
+  }
+
+  if (dostep[['par']]) {
+    if(!quietR & !is.null(PedParents)) {
       message(cli::col_green("\n~~~ Parentage assignment with pedigree-prior ~~~"))  # only sensible with Herm=A or B (?)
     } else if(!quietR) {
       message(cli::col_green("\n~~~ Parentage assignment ~~~"))
@@ -584,30 +580,28 @@ sequoia <- function(GenoM = NULL,
       SummarySeq(ParList, Panels="G.parents")
     }
 
-  } else if (Module != "dup" & "PedigreePar" %in% names(SeqList)) {  # don't include for 'dup'; confusing.
+  } else if (dostep[['ped']]) {  # PedigreePar provided as input
     ParList <- list(PedigreePar = PedParents)   # re-use assigned parents given as SeqList input (after polishing)
-  } else {
-    ParList <- NULL
   }
   utils::flush.console()
 
   # check that PedigreePar is a valid pedigree (no indiv is its own ancestor)
   W <- tryCatch.W.E(getGenerations(ParList$PedigreePar, StopIfInvalid=FALSE))$warning
-  if (!is.null(W)) {
-    if (Module=="ped")  cli::cli_alert_danger("Cancelling full pedigree reconstruction.")
+  if (!is.null(W) & dostep[['ped']]) {
+    dostep['ped'] <- FALSE
   }
 
 
   # Update ageprior ----
-  if (Module %in% c("par", "ped") & !"AgePriors" %in% names(SeqList) & is.null(W) &
+  if (any(dostep[c('par', 'ped')]) & !"AgePriors" %in% names(SeqList) & is.null(W) &
       !"PedigreePar" %in% names(SeqList) && !is.null(LifeHistData)) {
     if (Plot)  Sys.sleep(1)  # else no time to notice previous plot
     # in case MakeAgePrior throws error, do return parentage results:
     AgePriors <- tryCatch( do.call(MakeAgePrior,
                                    c(list(Pedigree = ParList$PedigreePar[, 1:3],
                                           LifeHistData = LifeHistData[LifeHistData$ID %in% rownames(GenoM),],
-                                          Plot = Plot & Module=="ped",
-                                          quiet = !(!quietR & Module=="ped")),
+                                          Plot = Plot & dostep['ped'],
+                                          quiet = !(!quietR & dostep['ped'])),
                                      args.AP)),
                            error = function(e) {
                              message("AgePrior error! \n", e)
@@ -626,7 +620,7 @@ sequoia <- function(GenoM = NULL,
 
 
   # @@ 4 @@ Full pedigree reconstruction ----
-  if (Module == "ped" & is.null(W)) {
+  if (dostep['ped']) {
     if (!all(apply(AgePriors, 2, function(x) any(x > 0))))
       stop("AgePriors error: some relationships are impossible for all age differences")
     if(!quietR)  message(cli::col_green("\n~~~ Full pedigree reconstruction ~~~"))
@@ -635,15 +629,18 @@ sequoia <- function(GenoM = NULL,
                          Parents = ParList$PedigreePar, mtDif=mtDif,
                          DumPfx = PARAM$DummyPrefix, quiet = quietR)
     ParList <- ParList[names(ParList) != "AgePriorExtra"]  # else included 2x w same name
-  } else SibList <- NULL
+  }
 
   #=====================
   # Output ----
 
-  if (quiet=='verbose' & Module %in% c('par', 'ped')) {
-    cli::cli_alert_info("You can use `SummarySeq()` for pedigree details, and `EstConf()` for confidence estimates")
-    cli::cli_alert_info(paste('Possibly not all', c(par = 'parents', ped = 'relatives')[as.character(Module)],
-    'were assigned, consider running `GetMaybeRel()` conditional on this pedigree to check'), wrap=TRUE)
+  if (quiet=='verbose' & any(dostep[c('par', 'ped')])) {
+    cli::cli_alert_info(paste("You can use `SummarySeq()` for pedigree details, ",
+                        "`CalcParentProbs()` for assignment probabilities, ",
+                        "and `EstConf()` for confidence estimates"), wrap=TRUE)
+    cli::cli_alert_info(paste('Run `GetMaybeRel()` conditional on this pedigree to check for any ',
+                              'non-assigned ', c(par = 'parents', ped = 'relatives')[as.character(Module)]),
+                              wrap=TRUE)
   }
 
   OUT <- list()
@@ -657,13 +654,12 @@ sequoia <- function(GenoM = NULL,
   }
   if (length(Excl)>0)  OUT <- c(OUT, Excl)
   if (length(OUT_LH)>0)  OUT <- c(OUT, OUT_LH)
-  OUT[["AgePriors"]] <- AgePriors
-  OUT[["LifeHist"]] <- LifeHistData
-  if (as.numeric(Module) > 1)  OUT <- c(OUT, DupList)
-  if (as.numeric(Module) > 2)  OUT <- c(OUT, ParList)
-  if (as.numeric(Module) > 3)  OUT <- c(OUT, SibList)
+  OUT <- c(OUT,
+           list(AgePriors = AgePriors,
+                LifeHist = LifeHistData),
+           DupList, ParList, SibList)
 
-  if (Plot & Module == "ped" & is.null(W)) {
+  if (Plot & dostep[['ped']]) {
     PlotAgePrior(OUT$AgePriorExtra)
     SummarySeq(OUT, Panels="G.parents")
   }
